==> haskell-conduit-extra-1.3.8-45-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-extra
version:              1.3.8
visibility:           public
id:                   conduit-extra-1.3.8-CgVZWFLveL3JOQpGK40p1j
key:                  conduit-extra-1.3.8-CgVZWFLveL3JOQpGK40p1j
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  997c0c5bab3998654026a7f50859cb29
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.8-CgVZWFLveL3JOQpGK40p1j
depends:
    async-2.2.5-DWviBtrYTc7K8qRxzPsJC
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    directory-1.3.7.1 filepath-1.4.2.2
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    primitive-0.9.1.0-CwYB76NvKpqXNq7rVKe89 process-1.6.18.0
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP stm-2.5.1.0
    streaming-commons-0.2.3.0-msDAcRqGslCe0T6zzs6il text-2.0.2
    transformers-0.5.6.2 typed-process-0.2.13.0-C7CM3qEvASAHKSm14GJwWH
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.3.8-64-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-extra
version:              1.3.8
visibility:           public
id:                   conduit-extra-1.3.8-1hrV1nPRDhE45dAx9zvo6P
key:                  conduit-extra-1.3.8-1hrV1nPRDhE45dAx9zvo6P
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  cbe893f5e8c43f5c2c237eabc259c3a2
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.8-1hrV1nPRDhE45dAx9zvo6P
depends:
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    directory-1.3.7.1 filepath-1.4.2.2
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    primitive-0.9.1.0-1TuYyil4nabJdMHni5vWH process-1.6.18.0
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl stm-2.5.1.0
    streaming-commons-0.2.3.0-7nYylEY3bibBf5EXMr0TCn text-2.0.2
    transformers-0.5.6.2 typed-process-0.2.13.0-375jfdUCZO6FyQcRPoVTB8
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
